/*
 * Functions for some floating control functional tests when it's actions have preferences.
 * @param {ProtractorBrowser} browser
 * @param {Browser} protractor
 * @constructor
 */
function FloatingControlUtilities(browser, protractor){

    var FrameworkConstructor = require('./../frameworkFunctionalTests.js');
    var z = new FrameworkConstructor(browser, protractor);
    var ec = protractor.ExpectedConditions;
    var self = this;

    /*
     * Determine whether the floating control action is opened.
     * @param {String} actionName - The action desired to be opened.
     */
    this.isActionOpened = function(actionName){
        var openedActionSelector = actionName + '-action opened';
        return element(by.css(openedActionSelector)).isPresent();
    };

    /*
     * Open the floating control action, testing if it is already opened.
     * @param {String} actionName - The action to be opened.
     */
    this.openAction = function(actionName){
        z.openFloatingControl();
        return this.isActionOpened(actionName).then(function(isActionOpened){
            if (!isActionOpened) {
                z.selectFloatingControlAction(actionName);
            }
        });
    };

    /**
     * Click on a floating control preference option, waiting it to be clickable.
     * @param {String} preferenceOption - The preference option label.
     */
    this.clickPreferenceOption = function(preferenceOption){
        var preferenceOptionLocator = '.zh-floating-control .float-action.opened div.floating-card-list .floating-preferences-options';
        z.clickElement(by.cssContainingText(preferenceOptionLocator, preferenceOption));
    };

    /**
     * Select the given preference option.
     * @param {String} preferenceOptionAction - The action that the preference option is related to.
     * @param {String} preferenceOption - The preference option to be selected.
     */
    this.selectPreferenceOption = function(preferenceOptionAction, preferenceOption){
        this.openAction(preferenceOptionAction).then(function(){
            self.clickPreferenceOption(preferenceOption);
        });
    };

}

module.exports = FloatingControlUtilities;